import React, { useEffect, useMemo } from 'react';
import { basename } from './modules/basename';
import { ToastContainer } from 'react-toastify';
import { useClientStore } from './store';
import { useConfigStore } from './store/config';
console.log('basename', basename);
const PackageManager = React.lazy(() => import('./package/index'));
const Enter = React.lazy(() => import('./page/Enter'));
export const App = () => {
  const url = new URL(window.location.href);
  const link = url.searchParams.get('link');
  const { checkClient, mount, isClient } = useClientStore();
  const { getConfig } = useConfigStore();
  useEffect(() => {
    checkClient();
  }, []);
  useEffect(() => {
    if (isClient) {
      getConfig();
    }
  }, [isClient]);
  const isEnter = useMemo(() => {
    if (!link) return true;
    return link.includes('enter');
  }, [link]);
  if (!mount)
    return (
      <div className='w-full h-full flex justify-center items-center'>
        <div className='w-10 h-10 bg-amber-500 rounded animate-spin'></div>
      </div>
    );
  return (
    <>
      <nav className='bg-amber-500 p-4 sticky top-0 z-10'>
        <ul className='flex space-x-4'>
          <li className={isEnter ? 'text-white' : 'text-white/70'}>
            <a href='?link=enter'>配置项</a>
          </li>
          <li className={!isEnter ? 'text-white' : 'text-white/70'}>
            <a href='?link=packages'>Packages</a>
          </li>
        </ul>
      </nav>
      <div className='w-full ' style={{ height: 'calc(100vh - 4rem)' }}>
        {isEnter ? <Enter /> : <PackageManager />}
      </div>
      <ToastContainer />
    </>
  );
};
