import React, { useEffect } from 'react';
import './Enter.css'; // Assuming you move the styles to a separate CSS file
import { useConfigStore } from '@/store/config';

const Enter: React.FC = () => {
  const { config, getConfig, saveConfig } = useConfigStore();
  useEffect(() => {
    createParticles();
    getConfig();
  }, []);
  useEffect(() => {
    if (config.pageApi) {
      const pageApi = document.getElementById('pageApi') as HTMLInputElement;
      pageApi.value = config.pageApi;
      const loadURL = document.getElementById('loadURL') as HTMLInputElement;
      loadURL.value = config.loadURL || '/web/note/';
    }
  }, [config]);
  const createParticles = () => {
    const particles = document.getElementById('particles');
    const particleCount = 20;

    if (particles) {
      for (let i = 0; i < particleCount; i++) {
        const particle = document.createElement('div');
        particle.className = 'particle';
        particle.innerHTML = `
                    <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round">
                        <path d="m12 3-1.912 5.813a2 2 0 0 1-1.275 1.275L3 12l5.813 1.912a2 2 0 0 1 1.275 1.275L12 21l1.912-5.813a2 2 0 0 1 1.275-1.275L21 12l-5.813-1.912a2 2 0 0 1-1.275-1.275L12 3Z"/>
                        <path d="M5 3v4"/>
                        <path d="M19 17v4"/>
                        <path d="M3 5h4"/>
                        <path d="M17 19h4"/>
                    </svg>
                `;

        const size = 10 + Math.random() * 20;
        particle.style.width = `${size}px`;
        particle.style.height = `${size}px`;

        particle.style.left = `${Math.random() * 100}%`;
        particle.style.top = `${Math.random() * 100}%`;
        particle.style.animationDuration = `${5 + Math.random() * 5}s`;
        particle.style.animationDelay = `${Math.random() * 5}s`;

        particles.appendChild(particle);
      }
    }
  };
  const onSave = () => {
    const pageApi = document.getElementById('pageApi') as HTMLInputElement;
    const loadURL = document.getElementById('loadURL') as HTMLInputElement;
    saveConfig({ pageApi: pageApi.value, loadURL: loadURL.value });
  };
  return (
    <div className='h-full w-full p-4 pt-10'>
      <div className='particles' id='particles'></div>
      <div className='container'>
        <div className='header'>
          <svg
            xmlns='http://www.w3.org/2000/svg'
            width='24'
            height='24'
            viewBox='0 0 24 24'
            fill='none'
            stroke='currentColor'
            strokeWidth='2'
            strokeLinecap='round'
            strokeLinejoin='round'>
            <path d='M12.22 2h-.44a2 2 0 0 0-2 2v.18a2 2 0 0 1-1 1.73l-.43.25a2 2 0 0 1-2 0l-.15-.08a2 2 0 0 0-2.73.73l-.22.38a2 2 0 0 0 .73 2.73l.15.1a2 2 0 0 1 1 1.72v.51a2 2 0 0 1-1 1.74l-.15.09a2 2 0 0 0-.73 2.73l.22.38a2 2 0 0 0 2.73.73l.15-.08a2 2 0 0 1 2 0l.43.25a2 2 0 0 1 1 1.73V20a2 2 0 0 0 2 2h.44a2 2 0 0 0 2-2v-.18a2 2 0 0 1 1-1.73l.43-.25a2 2 0 0 1 2 0l.15.08a2 2 0 0 0 2.73-.73l.22-.39a2 2 0 0 0-.73-2.73l-.15-.08a2 2 0 0 1-1-1.74v-.5a2 2 0 0 1 1-1.74l.15-.09a2 2 0 0 0 .73-2.73l-.22-.38a2 2 0 0 0-2.73-.73l-.15.08a2 2 0 0 1-2 0l-.43-.25a2 2 0 0 1-1-1.73V4a2 2 0 0 0-2-2z' />
            <circle cx='12' cy='12' r='3' />
          </svg>
          <h1>Page Enter Configuration</h1>
        </div>

        <div className='form-container'>
          <form id='configForm'>
            <div className='form-group'>
              <label htmlFor='pageApi'>Page Enter Api</label>
              <input type='text' id='pageApi' placeholder='Enter page api configuration' />
            </div>
            <div className='form-group'>
              <label htmlFor='loadURL'>Page Index</label>
              <input type='text' id='loadURL' placeholder='首页，例如: /web/note/' />
            </div>

            <button type='submit' id='save-button' onClick={onSave}>
              <svg
                xmlns='http://www.w3.org/2000/svg'
                width='20'
                height='20'
                viewBox='0 0 24 24'
                fill='none'
                stroke='currentColor'
                strokeWidth='2'
                strokeLinecap='round'
                strokeLinejoin='round'>
                <path d='M19 21H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h11l5 5v11a2 2 0 0 1-2 2z' />
                <polyline points='17 21 17 13 7 13 7 21' />
                <polyline points='7 3 7 8 15 8' />
              </svg>
              Save Configuration
            </button>
          </form>
          <div id='save-result'></div>
        </div>
      </div>
    </div>
  );
};

export default Enter;
