import { create } from 'zustand';
import { client } from '@/modules/query';
import { toast } from 'react-toastify';

type ConfigStore = {
  config: any;
  setConfig: (config: any) => void;
  getConfig: () => Promise<void>;
  saveConfig: (config: any) => Promise<void>;
  pageApi: string;
  setPageApi: (pageApi: string) => void;
  pageStoreApi: string;
  setPageStoreApi: (pageStoreApi: string) => void;
};

export const useConfigStore = create<ConfigStore>((set) => ({
  config: {},
  setConfig: (config) => set({ config }),
  getConfig: async () => {
    const res = await client.post({
      path: 'config',
    });
    if (res.code === 200) {
      console.log(res.data);
      set({ config: res.data, pageApi: res.data?.pageApi || '', pageStoreApi: res.data?.pageStoreApi || '' });
    } else {
      toast.error(res.message || '获取配置失败');
    }
  },
  pageApi: '',
  setPageApi: (pageApi) => set({ pageApi }),
  pageStoreApi: '',
  setPageStoreApi: (pageStoreApi) => set({ pageStoreApi }),
  saveConfig: async ({ pageApi, loadURL }) => {
    console.log(pageApi, loadURL);
    if (!pageApi) {
      toast.error('配置不能为空');
      return;
    }
    const res = await client.post({
      path: 'config',
      key: 'set',
      data: { pageApi, loadURL },
    });
    if (res.code === 200) {
      toast.success('保存配置成功');
    } else {
      toast.error(res.message || '保存配置失败');
    }
  },
}));
